@@ -8,7 +8,7 @@ use Text::Wrap   ();
 use Scalar::Util ();
 use version      ();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 my @m = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
 my %months = map { $m[ $_ ] => $_ + 1 } 0 .. 11;
@@ -203,6 +203,12 @@ sub release {
     return $self->{ releases }->{ $version };
 }
 
+sub delete_empty_groups {
+    my $self = shift;
+
+    $_->delete_empty_groups for $self->releases;
+}
+
 sub serialize {
     my $self = shift;
 
@@ -320,6 +326,10 @@ matching release object, undef is returned.
 Returns all of the data as a string, suitable for saving as a Changes 
 file.
 
+=head2 delete_empty_groups( )
+
+Deletes change groups without changes in all releases.
+
 =head1 DEALING WITH "NEXT VERSION" PLACEHOLDERS
 
 In the working copy of a distribution, it's not uncommon 
