@@ -7,7 +7,20 @@ use CPAN::Changes;
 use Test::Builder;
 
 my $Test       = Test::Builder->new;
-my $date_re    = '^\d{4}-\d{2}-\d{2}';    # "Looks like" a W3CDTF
+# From DateTime::Format::W3CDTF
+my $date_re    = qr{(\d\d\d\d) # Year
+                 (?:-(\d\d) # -Month
+                 (?:-(\d\d) # -Day
+                 (?:T
+                   (\d\d):(\d\d) # Hour:Minute
+                   (?:
+                     :(\d\d)     # :Second
+                     (\.\d+)?    # .Fractional_Second
+                   )?
+                   ( Z          # UTC
+                   | [+-]\d\d:\d\d    # Hour:Minute TZ offset
+                     (?::\d\d)?       # :Second TZ offset
+                 )?)?)?)?}x;
 my $version_re = '^[._\-[:alnum:]]+$';    # "Looks like" a version
 
 sub import {
@@ -51,7 +64,7 @@ sub changes_file_ok {
     $Test->ok( 1, "$file contains at least one release" );
 
     for ( @releases ) {
-        if ( $_->date !~ m{$date_re} ) {
+        if ( $_->date !~ m{^$date_re\s*$} ) {
             $Test->ok( 0, "$file contains an invalid release date" );
             $Test->diag( '  ERR: ' . $_->date );
             return;
